@@ -11,10 +11,10 @@ mod property_call;
 mod sigmaboolean;
 mod val_def_type_store;
 
-pub(crate) mod constant_store;
 pub(crate) mod op_code;
 pub(crate) mod types;
 
+pub mod constant_store;
 pub mod sigma_byte_reader;
 pub mod sigma_byte_writer;
 
